@@ -15,7 +15,9 @@ class MissionTypeData():
             "aggragate_type": 2,
             "comparison_type": 1,
             'timestamp_field': "start_time",
-            "operator_type": 1
+            "operator_type": 1,
+            "link_url": "/custom_course/user_live/",
+            "link_name": "去直播"
         },
         {
             "id": 1,
@@ -25,7 +27,9 @@ class MissionTypeData():
             "aggragate_type": 1,
             "comparison_type": 1,
             'timestamp_field': "created_at",
-            "operator_type": 0
+            "operator_type": 0,
+            "link_url": "",
+            "link_name": ""
         },
         {
             "id": 2,
@@ -35,17 +39,21 @@ class MissionTypeData():
             "aggragate_type": 1,
             "comparison_type": 1,
             "timestamp_field": None,
-            "operator_type": 0
+            "operator_type": 0,
+            "link_url": "",
+            "link_name": ""
         },
         {
             "id": 3,
             'name': '直播天数',
-            "field_name": "id",
+            "field_name": "start_time",
             "conditions": "status:1",
             "aggragate_type": 3,
             "comparison_type": 1,
             'timestamp_field': "start_time",
-            "operator_type": 0
+            "operator_type": 0,
+            "link_url": "/custom_course/user_live/",
+            "link_name": "去直播"
         },
         {
             "id": 4,
@@ -55,7 +63,9 @@ class MissionTypeData():
             "aggragate_type": 1,
             "comparison_type": 1,
             "timestamp_field": None,
-            "operator_type": 0
+            "operator_type": 0,
+            "link_url": "/course/user_course/",
+            "link_name": "去学习"
         },
 
     ]
@@ -196,17 +206,21 @@ class Command(BaseCommand):
         comparison_type = mission_type["comparison_type"]
         timestamp_field = mission_type["timestamp_field"]
         operator_type = mission_type["operator_type"]
+        link_url = mission_type["link_url"]
+        link_name = mission_type["link_name"]
         try:
             mt = MissionType.objects.get(name=name)
         except:
             mt = MissionType()
-            mt.name = name
-            mt.field_name = field_name
-            mt.conditions = conditions
-            mt.aggregate_type = aggregate_type
-            mt.comparison_type = comparison_type
-            mt.timestamp_field = timestamp_field
-            mt.operator_type = operator_type
-            mt.content_type = ct
-            mt.save()
+        mt.name = name
+        mt.field_name = field_name
+        mt.conditions = conditions
+        mt.aggregate_type = aggregate_type
+        mt.comparison_type = comparison_type
+        mt.timestamp_field = timestamp_field
+        mt.operator_type = operator_type
+        mt.content_type = ct
+        mt.link_name = link_name
+        mt.link_url = link_url
+        mt.save()
         return mt
