@@ -163,7 +163,7 @@ class MissionType(models.Model):
                                           default=1)  # 大于等于小于
     operator_type = models.IntegerField(verbose_name='对值运算', choices=MISSION_OPERATOR_TYPE_CHOICES,
                                         default=0)
-    conditions = models.TextField(verbose_name='其他附加条件', help_text='格式为：[条件1：值1，条件2：值2]，多个条件用,分割', null=True,
+    conditions = models.TextField(verbose_name='其他附加条件', help_text='格式为：[条件1：值1;条件2：值2]，多个条件用;分割', null=True,
                                   blank=True)
 
     link_url = models.CharField(max_length=180, null=True, blank=True, verbose_name='链接地址')
@@ -196,7 +196,6 @@ class Mission(models.Model):
         db_table = 'bee_django_mission'
         app_label = 'bee_django_mission'
         ordering = ['created_at']
-        verbose_name = '任务'
 
     def get_absolute_url(self):
         return reverse('bee_django_mission:mission_list')
@@ -514,6 +513,7 @@ class UserMission(models.Model):
     # 获取user_mission的完成情况
     # 返回【是否完成，已完成，要求，百分比】
     def get_user_mission_progress(self):
+        print(self.get_name())
         operator_type = self.mission.mission_type.operator_type  # 对count做运算
         count = self.get_count()
         # 前台显示用
@@ -537,7 +537,8 @@ class UserMission(models.Model):
         timestamp_field = self.mission.mission_type.timestamp_field
         comparison_type = self.mission.mission_type.comparison_type  # 大于等于小于
         conditions = self.mission.mission_type.conditions
-
+        if self.finish_at:
+            return True,0,0,0
         # 查询
         try:
             queryset = model.objects.all()
@@ -548,18 +549,20 @@ class UserMission(models.Model):
             # name_field = get_user_name_field()
             kwargs[user_field] = self.user_stage.user_line.user
             if conditions:
-                condition_list = conditions.split(',')
+                condition_list = conditions.split(';')
                 # print(condition_list)
                 for condition in condition_list:
                     # print(condition)
                     key = condition.split(':')[0]
                     value = condition.split(':')[1]
+                    if value in ["true","True"]:
+                        value=True
+                    elif value in ["false","False"]:
+                        value=False
                     kwargs[key] = value
             # 周任务
             if self.user_stage.user_line.line.is_week_line():
                 kwargs[timestamp_field + "__range"] = [self.user_stage.start_at, self.user_stage.end_at]
-
-            # print(kwargs)
             queryset = queryset.filter(**kwargs)
             if queryset.count() == 0:
                 return False, 0, show_require, 0
@@ -577,7 +580,7 @@ class UserMission(models.Model):
                 queryset["_agg"] = _queryset.count()
 
             else:
-                return False, 0, 0
+                return False, 0, 0,0
             # 比较
             if comparison_type == 1:
                 res = queryset["_agg"] >= count
@@ -585,7 +588,6 @@ class UserMission(models.Model):
                 res = queryset["_agg"] > count
             else:
                 res = None
-            # print(res)
             if operator_type == 1:
                 show_finish = queryset["_agg"] / 60
             else:
@@ -594,22 +596,15 @@ class UserMission(models.Model):
                 percent = 100
             else:
                 percent = show_finish * 100 / show_require
-            if self.finish_at:
-                return True, show_finish, show_require, percent
-            else:
-                if res:
-                    # print('finished')
-                    self.finish_at = get_now()
-                    self.save()
-                    return True, show_finish, show_require, percent
-                else:
-
-                    # print(queryset["_agg"])
-                    # print('not finished')
-                    return False, show_finish, show_require, percent
 
+            if res:
+                # print('finished')
+                self.finish_at = get_now()
+                self.save()
+            return res, show_finish, show_require, percent
 
         except Exception as e:
+            print('=model.get_user_mission_progress=')
             print(e)
         return False, 0, 0
 
