@@ -30,3 +30,7 @@ def get_int(a):
 @register.filter
 def local_datetime(_datetime):
     return filter_local_datetime(_datetime)
+
+@register.simple_tag
+def get_mission_progress(user_mission):
+    return user_mission.get_user_mission_progress()
\ No newline at end of file
