@@ -237,7 +237,7 @@ class UserMissionListWeek(TemplateView):
         user_stage.update_user_stage_status()
         # 取值
         user_stage_list = user_line.get_user_all_stage()
-        user_mission_list = UserMission.objects.filter(user_stage=user_stage)
+        user_mission_list = UserMission.objects.filter(user_stage=user_stage).order_by('mission__order_by')
         context["user_stage"] = user_stage
         context["user_stage_list"] = user_stage_list
         context["user_mission_list"] = user_mission_list
@@ -339,6 +339,8 @@ class UserStageDetail(DetailView):
         context["user_mission_list"] = user_mission_list
         return context
 
+class CustomUserStageDetail(UserStageDetail):
+    template_name = ''
 
 class UserStageUpdateStatus(TemplateView):
     def post(self, request, *args, **kwargs):
